@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,14 +14,25 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the gzip program."""
-from . import extract_singlefile_standard, \
-    test_singlefile_standard, create_singlefile_standard
+from . import extract_singlefile_standard, test_singlefile_standard
+from .. import util
 
 extract_gzip = extract_compress = extract_singlefile_standard
 test_gzip = test_compress = test_singlefile_standard
-create_gzip = create_singlefile_standard
 
-def list_gzip (archive, compression, cmd, verbosity):
+
+def create_gzip(archive, compression, cmd, verbosity, interactive, filenames):
+    """Create a GZIP archive."""
+    cmdlist = [util.shell_quote(cmd)]
+    if verbosity > 1:
+        cmdlist.append('-v')
+    cmdlist.extend(['-c', '-9', '--'])
+    cmdlist.extend([util.shell_quote(x) for x in filenames])
+    cmdlist.extend(['>', util.shell_quote(archive)])
+    return (cmdlist, {'shell': True})
+
+
+def list_gzip (archive, compression, cmd, verbosity, interactive):
     """List a GZIP archive."""
     cmdlist = [cmd]
     if verbosity > 0:
