@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,4 +45,5 @@ from .p7zip import \
   test_7z, \
   create_7z, \
   create_zip, \
-  create_gzip
+  create_gzip, \
+  create_bzip2
