@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 """Archive commands for the rzip program."""
 from .. import util
 
-def extract_rzip (archive, compression, cmd, verbosity, outdir):
+def extract_rzip (archive, compression, cmd, verbosity, interactive, outdir):
     """Extract an RZIP archive."""
     cmdlist = [cmd, '-d', '-k']
     if verbosity > 1:
@@ -25,9 +25,9 @@ def extract_rzip (archive, compression, cmd, verbosity, outdir):
     cmdlist.extend(["-o", outfile, archive])
     return cmdlist
 
-def create_rzip (archive, compression, cmd, verbosity, filenames):
+def create_rzip (archive, compression, cmd, verbosity, interactive, filenames):
     """Create an RZIP archive."""
-    cmdlist = [cmd, '-k', '-o', archive]
+    cmdlist = [cmd, '-k', '-9', '-o', archive]
     if verbosity > 1:
         cmdlist.append('-v')
     cmdlist.extend(filenames)
