@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,16 +15,16 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the zip program."""
 
-def create_zip (archive, compression, cmd, verbosity, filenames):
+def create_zip (archive, compression, cmd, verbosity, interactive, filenames):
     """Create a ZIP archive."""
-    cmdlist = [cmd, '-r']
+    cmdlist = [cmd, '-r', '-9']
     if verbosity > 1:
         cmdlist.append('-v')
     cmdlist.append(archive)
     cmdlist.extend(filenames)
     return cmdlist
 
-def test_zip (archive, compression, cmd, verbosity):
+def test_zip (archive, compression, cmd, verbosity, interactive):
     """Test a ZIP archive."""
     cmdlist = [cmd, '--test']
     if verbosity > 1:
