@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2016 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +25,16 @@ class TestUnzip (ArchiveTest):
         self.archive_extract('t.zip', check=None)
         self.archive_list('t.zip')
         self.archive_test('t.zip')
+        self.archive_extract('t.cbz', check=None)
+        self.archive_list('t.cbz')
+        self.archive_test('t.cbz')
         self.archive_extract('t.jar', check=None)
         self.archive_list('t.jar')
         self.archive_test('t.jar')
         self.archive_extract('t.epub', check=None)
         self.archive_list('t.epub')
         self.archive_test('t.epub')
+        self.archive_extract('t.apk', check=None)
         self.archive_list('t.apk')
         self.archive_test('t.apk')
 
@@ -40,11 +44,15 @@ class TestUnzip (ArchiveTest):
         self.archive_extract('t.zip.foo', check=None)
         self.archive_list('t.zip.foo')
         self.archive_test('t.zip.foo')
+        self.archive_extract('t.cbz.foo', check=None)
+        self.archive_list('t.cbz.foo')
+        self.archive_test('t.cbz.foo')
         self.archive_extract('t.jar.foo', check=None)
         self.archive_list('t.jar.foo')
         self.archive_test('t.jar.foo')
         self.archive_extract('t.epub.foo', check=None)
         self.archive_list('t.epub.foo')
         self.archive_test('t.epub.foo')
+        self.archive_extract('t.apk.foo', check=None)
         self.archive_list('t.apk.foo')
         self.archive_test('t.apk.foo')
