@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,4 +27,4 @@ class ArchiveDiffTest (unittest.TestCase):
     def test_diff (self):
         archive1 = os.path.join(datadir, "t.tar")
         archive2 = os.path.join(datadir, "t.zip")
-        run_checked([sys.executable, patool_cmd, "-vv", "diff", archive1, archive2])
+        run_checked([sys.executable, patool_cmd, "-vv", "--non-interactive", "diff", archive1, archive2])
