@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@ from . import patool_cmd
 class TestFormats (unittest.TestCase):
 
     def test_list_formats (self):
-        run_checked([sys.executable, patool_cmd, "-vv", 'formats'])
+        run_checked([sys.executable, patool_cmd, "-vv", "--non-interactive", 'formats'])
